@@ -3,6 +3,7 @@ import os
 import subprocess
 import sys
 from collections import namedtuple
+import contextlib
 
 import wordcloud as wc
 from wordcloud import wordcloud_cli as cli
@@ -161,13 +162,9 @@ def test_cli_writes_to_stdout(tmpdir, tmp_text_file):
 
     tmp_text_file.write(b'some text')
 
-    originalBuffer = sys.stdout.buffer
-    sys.stdout.buffer = tmp_image_file.open('wb+')
-
-    args, text, image_file = cli.parse_args(['--text', str(tmp_text_file)])
-    cli.main(args, text, image_file)
-
-    sys.stdout.buffer = originalBuffer
+    with contextlib.redirect_stdout(tmp_image_file.open('w+')):
+        args, text, image_file = cli.parse_args(['--text', str(tmp_text_file)])
+        cli.main(args, text, image_file)
 
     # expecting image to be written to stdout
     assert tmp_image_file.size() > 0
@@ -187,8 +184,8 @@ def test_cli_regexp_invalid(tmp_text_file, capsys):
 
 @pytest.mark.parametrize("command,expected_output, expected_exit_code", [
     ("wordcloud_cli --help", "usage: wordcloud_cli", 0),
-    ("python -m wordcloud --help", "usage: __main__", 0),
-    ("python %s/../wordcloud/wordcloud_cli.py --help" % os.path.dirname(__file__), "To execute the CLI", 1),
+    ("%s -m wordcloud --help" % sys.executable, "usage: __main__", 0),
+    ("%s %s/../wordcloud/wordcloud_cli.py --help" % (sys.executable, os.path.dirname(__file__)), "To execute the CLI", 1),
 ])
 def test_cli_as_executable(command, expected_output, expected_exit_code, tmpdir, capfd, no_cover_compat):
 
