@@ -290,13 +290,15 @@ class WordCloud(object):
         .. versionchanged: 2.0
             ``words_`` is now a dictionary
 
-    ``layout_`` : list of tuples (string, int, (int, int), int, color))
-        Encodes the fitted word cloud. Encodes for each word the string, font
-        size, position, orientation and color.
+    ``layout_`` : list of tuples ((string, float), int, (int, int), int, color))
+        Encodes the fitted word cloud. For each word, it encodes the string, 
+        normalized frequency, font size, position, orientation, and color.
+        The frequencies are normalized by the most commonly occurring word.
+        The color is in the format of 'rgb(R, G, B).'
 
     Notes
     -----
-    Larger canvases with make the code significantly slower. If you need a
+    Larger canvases make the code significantly slower. If you need a
     large word cloud, try a lower canvas size, and set the scale parameter.
 
     The algorithm might give more weight to the ranking of the words
@@ -365,6 +367,11 @@ class WordCloud(object):
         self.min_word_length = min_word_length
         self.collocation_threshold = collocation_threshold
 
+        # Override the width and height if there is a mask
+        if mask is not None:
+            self.width = mask.shape[1]
+            self.height = mask.shape[0]
+
     def fit_words(self, frequencies):
         """Create a word_cloud from words and frequencies.
 
@@ -739,9 +746,6 @@ class WordCloud(object):
         """
         return self.to_array()
 
-    def to_html(self):
-        raise NotImplementedError("FIXME!!!")
-
     def to_svg(self, embed_font=False, optimize_embedded_font=True, embed_image=False):
         """Export to SVG.
 
